Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(507)

Unified Diff: chrome/browser/tab_restore_uitest.cc

Issue 7064052: Revert 88142 to fix sync_integration_tests offline. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: Created 9 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/tab_contents/render_view_context_menu.cc ('k') | chrome/browser/tabs/tab_strip_model.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/tab_restore_uitest.cc
===================================================================
--- chrome/browser/tab_restore_uitest.cc (revision 88158)
+++ chrome/browser/tab_restore_uitest.cc (working copy)
@@ -602,7 +602,7 @@
EXPECT_TRUE(url == url2_);
}
// Restore tab with special URL chrome://credits/ and make sure the page loads
// properly after restore. See http://crbug.com/31905.
TEST_F(TabRestoreUITest, RestoreTabWithSpecialURL) {
scoped_refptr<BrowserProxy> browser(automation()->GetBrowserWindow(0));
@@ -610,7 +610,7 @@
CheckActiveWindow(browser.get());
// Navigate new tab to a special URL.
- const GURL special_url(chrome::kChromeUICreditsURL);
+ const GURL special_url(chrome::kAboutCreditsURL);
ASSERT_TRUE(browser->AppendTab(special_url));
scoped_refptr<TabProxy> tab(browser->GetActiveTab());
ASSERT_TRUE(tab.get());
@@ -643,7 +643,7 @@
CheckActiveWindow(browser.get());
// Navigate new tab to a special URL.
- const GURL special_url(chrome::kChromeUICreditsURL);
+ const GURL special_url(chrome::kAboutCreditsURL);
ASSERT_TRUE(browser->AppendTab(special_url));
scoped_refptr<TabProxy> tab(browser->GetActiveTab());
ASSERT_TRUE(tab.get());
@@ -602,7 +602,7 @@
EXPECT_TRUE(url == url2_);
}
-// Restore tab with special URL chrome://credits/ and make sure the page loads
+// Restore tab with special URL about:credits and make sure the page loads
// properly after restore. See http://crbug.com/31905.
TEST_F(TabRestoreUITest, RestoreTabWithSpecialURL) {
« no previous file with comments | « chrome/browser/tab_contents/render_view_context_menu.cc ('k') | chrome/browser/tabs/tab_strip_model.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698